use std::{fs, path::Path};

use part::Parts;

mod law;
mod part;

fn main() {
    fs::create_dir_all("./output").unwrap();

    let overview = law::create_law_files();
    create_static_files();

    create_index(&overview);
}

/// Creates the `index.html` file.
fn create_index(content: &str) {
    let mut index = fs::read_to_string("templates/index.html").unwrap();
    index = index.replace("{{content}}", content);
    let index = Parts::new().perform(index);
    fs::write("output/index.html", index).expect("Unable to write file");
}

/// Copies all files from `templates/static` to `output`
fn create_static_files() {
    let from = Path::new("templates/static");
    let to = Path::new("output");

    for entry in fs::read_dir(from).expect("No templates/static folder") {
        let entry = entry.unwrap();
        let path = entry.path();
        if path.is_file() {
            let to_path = to.join(entry.file_name());
            fs::copy(&path, &to_path).unwrap();
        }
    }
}
